@@ -1,5 +1,5 @@
 /*
- * $Id: cdk.h,v 1.34 2004/08/29 21:49:32 tom Exp $
+ * $Id: cdk.h,v 1.39 2024/03/31 17:38:42 tom Exp $
  */
 
 #ifndef CDK_H
@@ -10,38 +10,31 @@ extern "C" {
 #endif
 
 /*
- * Changes 2000-2003,2004 copyright Thomas E. Dickey
- *
+ * Changes 2000-2012,2024 copyright Thomas E. Dickey
  * Copyright 1999, Mike Glover
- * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- * 	This product includes software developed by Mike Glover
- * 	and contributors.
- * 4. Neither the name of Mike Glover, nor the names of contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to
+ * deal in the Software without restriction, including without limitation the
+ * rights to use, copy, modify, merge, publish, distribute, distribute with
+ * modifications, sublicense, and/or sell copies of the Software, and to permit
+ * persons to whom the Software is furnished to do so, subject to the following
+ * conditions:
  *
- * THIS SOFTWARE IS PROVIDED BY MIKE GLOVER AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL MIKE GLOVER OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+ * ABOVE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
+ * IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ *
+ * Except as contained in this notice, the name(s) of the above copyright
+ * holders shall not be used in advertising or otherwise to promote the sale,
+ * use or other dealings in this Software without prior written authorization.
  */
 
 #include <cdk/cdk_config.h>
@@ -54,16 +47,16 @@ extern "C" {
 #ifdef HAVE_XCURSES
 #include <xcurses.h>
 #ifndef mvwhline
-#define mvwhline(win,y,x,c,n)     	(wmove(win,y,x) == ERR ? ERR : whline(win,c,n))
+#define mvwhline(win,y,x,c,n)     (wmove(win,y,x) == ERR ? ERR : whline(win,c,n))
 #endif
 #ifndef mvwvline
-#define mvwvline(win,y,x,c,n)     	(wmove(win,y,x) == ERR ? ERR : wvline(win,c,n))
+#define mvwvline(win,y,x,c,n)     (wmove(win,y,x) == ERR ? ERR : wvline(win,c,n))
 #endif
 #elif defined(HAVE_NCURSESW_NCURSES_H)
 #include <ncursesw/ncurses.h>
 #elif defined(HAVE_NCURSES_NCURSES_H)
 #include <ncurses/ncurses.h>
-#elif defined(HAVE_NCURSES_H)
+#elif defined(CDK_HAVE_NCURSES_H)
 #include <ncurses.h>
 #else
 #include <curses.h>
@@ -75,19 +68,26 @@ extern "C" {
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#ifdef CDK_HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef CDK_HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <time.h>
 #include <errno.h>
+#ifdef CDK_HAVE_PWD_H
 #include <pwd.h>
+#endif
+#ifdef CDK_HAVE_GRP_H
 #include <grp.h>
-
-#ifdef HAVE_LIMITS_H
+#endif
+#ifdef CDK_HAVE_LIMITS_H
 #include <limits.h>
 #endif
 
-#ifdef HAVE_GETOPT_HEADER
-#ifdef HAVE_GETOPT_H
+#ifdef CDK_HAVE_GETOPT_HEADER
+#ifdef CDK_HAVE_GETOPT_H
 #include <getopt.h>
 #endif
 #else
@@ -217,7 +217,7 @@ typedef enum {vFRONT, vBACK, vBOTH} EStripType;
  * This enumerated typedef defines the type of exits the widgets
  * recognize.
  */
-typedef enum {vEARLY_EXIT, vESCAPE_HIT, vNORMAL, vNEVER_ACTIVATED} EExitType;
+typedef enum {vEARLY_EXIT, vESCAPE_HIT, vNORMAL, vNEVER_ACTIVATED, vERROR} EExitType;
 
 /*
  * This defines a boolean type.
@@ -264,9 +264,9 @@ extern  FILE	*CDKDEBUG;
  */
 #define START_DEBUG(a)		(CDKDEBUG=startCDKDebug(a))
 #define WRITE_DEBUGMESG(a,b)	(writeCDKDebugMessage (CDKDEBUG,__FILE__,a,__LINE__,b))
-#define	END_DEBUG		(stopCDKDebug(CDKDEBUG)
-FILE *startCDKDebug(char *filename);
-void writeCDKDebugMessage (FILE *fd, char *filename, char *function, int line, char *message);
+#define	END_DEBUG()		(stopCDKDebug(CDKDEBUG))
+FILE *startCDKDebug(const char *filename);
+void writeCDKDebugMessage (FILE *fd, const char *filename, const char *function, int line, const char *message);
 void stopCDKDebug (FILE *fd);
 
 /*
