@@ -4,44 +4,38 @@
 
 #ifndef CDK_H
 #define CDKINCLUDES
-#include <cdk/cdk.h>
+#include <cdk.h>
 #undef CDKINCLUDES
 #endif
 
 /*
- * $Id: curdefs.h,v 1.13 2004/08/30 23:57:07 tom Exp $
+ * $Id: curdefs.h,v 1.17 2009/02/16 00:33:50 tom Exp $
  *
- * Changes 1999-2002,2004 copyright Thomas E. Dickey
+ * Copyright 1999-2004,2009 Thomas E. Dickey
  * Copyright 1999, Mike Glover
- * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- * 	This product includes software developed by Mike Glover
- * 	and contributors.
- * 4. Neither the name of Mike Glover, nor the names of contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to
+ * deal in the Software without restriction, including without limitation the
+ * rights to use, copy, modify, merge, publish, distribute, distribute with
+ * modifications, sublicense, and/or sell copies of the Software, and to permit
+ * persons to whom the Software is furnished to do so, subject to the following
+ * conditions:
  *
- * THIS SOFTWARE IS PROVIDED BY MIKE GLOVER AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL MIKE GLOVER OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+ * ABOVE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+ * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
+ * IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ *
+ * Except as contained in this notice, the name(s) of the above copyright
+ * holders shall not be used in advertising or otherwise to promote the sale,
+ * use or other dealings in this Software without prior written authorization.
  */
 
 /*
@@ -112,6 +106,8 @@
 #undef  KEY_F12
 #define KEY_F12		KEY_F(12)
 
+#define KEY_ERROR       ((chtype)ERR)
+
 /* these definitions may work for antique versions of curses */
 #if	!defined(HAVE_GETBEGYX) && !defined(getbegyx)
 #define getbegyx(win,y,x)	(y = (win)?(win)->_begy:ERR, x = (win)?(win)->_begx:ERR)
@@ -122,7 +118,7 @@
 #endif
 
 /* these definitions may be needed for bleeding-edge curses implementations */
-#if !(defined(HAVE_GETBEGX) && defined(HAVE_GETBEGY))
+#if !(defined(CDK_HAVE_GETBEGX) && defined(CDK_HAVE_GETBEGY))
 #undef getbegx
 #undef getbegy
 #define getbegx(win) cdk_getbegx(win)
@@ -131,7 +127,7 @@ extern int cdk_getbegx(WINDOW *);
 extern int cdk_getbegy(WINDOW *);
 #endif
 
-#if !(defined(HAVE_GETMAXX) && defined(HAVE_GETMAXY))
+#if !(defined(CDK_HAVE_GETMAXX) && defined(CDK_HAVE_GETMAXY))
 #undef getmaxx
 #undef getmaxy
 #define getmaxx(win) cdk_getmaxx(win)
